# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/ConstantsAllocations.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class ConstantsAllocations(genpy.Message):
  _md5sum = "0e65410f8bbf9d0fbe3392f0010d87ed"
  _type = "digitaleye_msgs/ConstantsAllocations"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Constants regarding allocations
# CONFORMANCE STATUS
uint32 CONF_UNKNOWN=1 # no allocation found to conform to
uint32 CONF_KO_ALLOCATION=2 #
uint32 CONF_KO_EXPIRED=3
uint32 CONF_OK=4

# Allocations categories
uint32 ALLOC_CAT_TOLZ=0
uint32 ALLOC_CAT_CORRIDOR=1
uint32 ALLOC_CAT_LOI=2
uint32 ALLOC_CAT_SIZE=3

# Sector categories
uint32 SECTOR_CAT_MAS=0
uint32 SECTOR_CAT_MGS=1
uint32 SECTOR_CAT_BOARDING=2
"""
  # Pseudo-constants
  CONF_UNKNOWN = 1
  CONF_KO_ALLOCATION = 2
  CONF_KO_EXPIRED = 3
  CONF_OK = 4
  ALLOC_CAT_TOLZ = 0
  ALLOC_CAT_CORRIDOR = 1
  ALLOC_CAT_LOI = 2
  ALLOC_CAT_SIZE = 3
  SECTOR_CAT_MAS = 0
  SECTOR_CAT_MGS = 1
  SECTOR_CAT_BOARDING = 2

  __slots__ = []
  _slot_types = []

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(ConstantsAllocations, self).__init__(*args, **kwds)

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      pass
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      pass
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
