# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/ConformanceUavStatus.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class ConformanceUavStatus(genpy.Message):
  _md5sum = "195225b2b8449010b98306c7f2dde4a7"
  _type = "digitaleye_msgs/ConformanceUavStatus"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Conformance status details for a UAV

# unique internal UAV id
uint64 uav_id

# state of the conformance of the UAV
# using CONF_ constants
uint32 conformance_state

# indicator of the position of the UAV
# - true: inside MAS
# - false: outside of MAS but inside of extended MAS
bool is_inside_MAS
"""
  __slots__ = ['uav_id','conformance_state','is_inside_MAS']
  _slot_types = ['uint64','uint32','bool']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       uav_id,conformance_state,is_inside_MAS

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(ConformanceUavStatus, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.uav_id is None:
        self.uav_id = 0
      if self.conformance_state is None:
        self.conformance_state = 0
      if self.is_inside_MAS is None:
        self.is_inside_MAS = False
    else:
      self.uav_id = 0
      self.conformance_state = 0
      self.is_inside_MAS = False

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_QIB().pack(_x.uav_id, _x.conformance_state, _x.is_inside_MAS))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      _x = self
      start = end
      end += 13
      (_x.uav_id, _x.conformance_state, _x.is_inside_MAS,) = _get_struct_QIB().unpack(str[start:end])
      self.is_inside_MAS = bool(self.is_inside_MAS)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_QIB().pack(_x.uav_id, _x.conformance_state, _x.is_inside_MAS))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      _x = self
      start = end
      end += 13
      (_x.uav_id, _x.conformance_state, _x.is_inside_MAS,) = _get_struct_QIB().unpack(str[start:end])
      self.is_inside_MAS = bool(self.is_inside_MAS)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_QIB = None
def _get_struct_QIB():
    global _struct_QIB
    if _struct_QIB is None:
        _struct_QIB = struct.Struct("<QIB")
    return _struct_QIB
